@@ -111,8 +111,11 @@ class Hypervisor(object):
 
 			http://kb.vmware.com/selfservice/microsites/search.do?language=en_US&cmd=displayKC&externalId=1009458
 		"""
-		return self.system.bios_vendor.startswith("VMWare-") and \
-			_fireinfo.vmware_hypervisor_port_check()
+		if self.system.vendor:
+			return self.system.vendor.startswith("VMware")
+
+			# XXX We should use _fireinfo.vmware_hypervisor_port_check() here, too.
+			# This currently segfaults (and I have no clue why) on VMware player.
 
 	def __is_hypervisor_qemu(self):
 		"""
